# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/inter_adapter.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/inter_adapter.proto',
  package='inter_adapter',
  syntax='proto3',
  serialized_options=b'\n!org.opencord.voltha.inter_adapterZ5github.com/opencord/voltha-protos/v5/go/inter_adapter',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!voltha_protos/inter_adapter.proto\x12\rinter_adapter\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a voltha_protos/tech_profile.proto\x1a\x1bvoltha_protos/openolt.proto\x1a\x1avoltha_protos/device.proto\"\xba\x01\n\x0bOmciMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12\x18\n\x10parent_device_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63hild_device_id\x18\x05 \x01(\t\"\xbc\x01\n\x0cOmciMessages\x12\x10\n\x08messages\x18\x01 \x03(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12\x18\n\x10parent_device_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63hild_device_id\x18\x05 \x01(\t\"\xea\x01\n\x1aTechProfileDownloadMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x38\n\x0btp_instance\x18\x04 \x01(\x0b\x32!.tech_profile.TechProfileInstanceH\x00\x12\x41\n\x10\x65pon_tp_instance\x18\x05 \x01(\x0b\x32%.tech_profile.EponTechProfileInstanceH\x00\x42\x12\n\x10tech_tp_instance\"h\n\x14\x44\x65leteGemPortMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x13\n\x0bgem_port_id\x18\x04 \x01(\r\"c\n\x12\x44\x65leteTcontMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\x04 \x01(\r\"Y\n\x14OnuIndicationMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12.\n\x0eonu_indication\x18\x02 \x01(\x0b\x32\x16.openolt.OnuIndication\"\xa3\x01\n!TechProfileInstanceRequestMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10tp_instance_path\x18\x02 \x01(\t\x12\x18\n\x10parent_device_id\x18\x03 \x01(\t\x12\x17\n\x0fparent_pon_port\x18\x04 \x01(\r\x12\x0e\n\x06onu_id\x18\x05 \x01(\r\x12\x0e\n\x06uni_id\x18\x06 \x01(\rBZ\n!org.opencord.voltha.inter_adapterZ5github.com/opencord/voltha-protos/v5/go/inter_adapterb\x06proto3'
  ,
  dependencies=[voltha__protos_dot_common__pb2.DESCRIPTOR,voltha__protos_dot_voltha__pb2.DESCRIPTOR,voltha__protos_dot_tech__profile__pb2.DESCRIPTOR,voltha__protos_dot_openolt__pb2.DESCRIPTOR,voltha__protos_dot_device__pb2.DESCRIPTOR,])




_OMCIMESSAGE = _descriptor.Descriptor(
  name='OmciMessage',
  full_name='inter_adapter.OmciMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='inter_adapter.OmciMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_status', full_name='inter_adapter.OmciMessage.connect_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_address', full_name='inter_adapter.OmciMessage.proxy_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='inter_adapter.OmciMessage.parent_device_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device_id', full_name='inter_adapter.OmciMessage.child_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=386,
)


_OMCIMESSAGES = _descriptor.Descriptor(
  name='OmciMessages',
  full_name='inter_adapter.OmciMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='inter_adapter.OmciMessages.messages', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connect_status', full_name='inter_adapter.OmciMessages.connect_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy_address', full_name='inter_adapter.OmciMessages.proxy_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='inter_adapter.OmciMessages.parent_device_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_device_id', full_name='inter_adapter.OmciMessages.child_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=577,
)


_TECHPROFILEDOWNLOADMESSAGE = _descriptor.Descriptor(
  name='TechProfileDownloadMessage',
  full_name='inter_adapter.TechProfileDownloadMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='inter_adapter.TechProfileDownloadMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='inter_adapter.TechProfileDownloadMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='inter_adapter.TechProfileDownloadMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance', full_name='inter_adapter.TechProfileDownloadMessage.tp_instance', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epon_tp_instance', full_name='inter_adapter.TechProfileDownloadMessage.epon_tp_instance', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tech_tp_instance', full_name='inter_adapter.TechProfileDownloadMessage.tech_tp_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=580,
  serialized_end=814,
)


_DELETEGEMPORTMESSAGE = _descriptor.Descriptor(
  name='DeleteGemPortMessage',
  full_name='inter_adapter.DeleteGemPortMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='inter_adapter.DeleteGemPortMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='inter_adapter.DeleteGemPortMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='inter_adapter.DeleteGemPortMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gem_port_id', full_name='inter_adapter.DeleteGemPortMessage.gem_port_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=816,
  serialized_end=920,
)


_DELETETCONTMESSAGE = _descriptor.Descriptor(
  name='DeleteTcontMessage',
  full_name='inter_adapter.DeleteTcontMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='inter_adapter.DeleteTcontMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='inter_adapter.DeleteTcontMessage.uni_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='inter_adapter.DeleteTcontMessage.tp_instance_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='inter_adapter.DeleteTcontMessage.alloc_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1021,
)


_ONUINDICATIONMESSAGE = _descriptor.Descriptor(
  name='OnuIndicationMessage',
  full_name='inter_adapter.OnuIndicationMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='inter_adapter.OnuIndicationMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_indication', full_name='inter_adapter.OnuIndicationMessage.onu_indication', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1112,
)


_TECHPROFILEINSTANCEREQUESTMESSAGE = _descriptor.Descriptor(
  name='TechProfileInstanceRequestMessage',
  full_name='inter_adapter.TechProfileInstanceRequestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='inter_adapter.TechProfileInstanceRequestMessage.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tp_instance_path', full_name='inter_adapter.TechProfileInstanceRequestMessage.tp_instance_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_device_id', full_name='inter_adapter.TechProfileInstanceRequestMessage.parent_device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_pon_port', full_name='inter_adapter.TechProfileInstanceRequestMessage.parent_pon_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='inter_adapter.TechProfileInstanceRequestMessage.onu_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='inter_adapter.TechProfileInstanceRequestMessage.uni_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1115,
  serialized_end=1278,
)

_OMCIMESSAGE.fields_by_name['connect_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_OMCIMESSAGE.fields_by_name['proxy_address'].message_type = voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS
_OMCIMESSAGES.fields_by_name['connect_status'].enum_type = voltha__protos_dot_common__pb2._CONNECTSTATUS_TYPES
_OMCIMESSAGES.fields_by_name['proxy_address'].message_type = voltha__protos_dot_device__pb2._DEVICE_PROXYADDRESS
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'].message_type = voltha__protos_dot_tech__profile__pb2._TECHPROFILEINSTANCE
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'].message_type = voltha__protos_dot_tech__profile__pb2._EPONTECHPROFILEINSTANCE
_TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance'].fields.append(
  _TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'])
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['tp_instance'].containing_oneof = _TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance']
_TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance'].fields.append(
  _TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'])
_TECHPROFILEDOWNLOADMESSAGE.fields_by_name['epon_tp_instance'].containing_oneof = _TECHPROFILEDOWNLOADMESSAGE.oneofs_by_name['tech_tp_instance']
_ONUINDICATIONMESSAGE.fields_by_name['onu_indication'].message_type = voltha__protos_dot_openolt__pb2._ONUINDICATION
DESCRIPTOR.message_types_by_name['OmciMessage'] = _OMCIMESSAGE
DESCRIPTOR.message_types_by_name['OmciMessages'] = _OMCIMESSAGES
DESCRIPTOR.message_types_by_name['TechProfileDownloadMessage'] = _TECHPROFILEDOWNLOADMESSAGE
DESCRIPTOR.message_types_by_name['DeleteGemPortMessage'] = _DELETEGEMPORTMESSAGE
DESCRIPTOR.message_types_by_name['DeleteTcontMessage'] = _DELETETCONTMESSAGE
DESCRIPTOR.message_types_by_name['OnuIndicationMessage'] = _ONUINDICATIONMESSAGE
DESCRIPTOR.message_types_by_name['TechProfileInstanceRequestMessage'] = _TECHPROFILEINSTANCEREQUESTMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OmciMessage = _reflection.GeneratedProtocolMessageType('OmciMessage', (_message.Message,), {
  'DESCRIPTOR' : _OMCIMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.OmciMessage)
  })
_sym_db.RegisterMessage(OmciMessage)

OmciMessages = _reflection.GeneratedProtocolMessageType('OmciMessages', (_message.Message,), {
  'DESCRIPTOR' : _OMCIMESSAGES,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.OmciMessages)
  })
_sym_db.RegisterMessage(OmciMessages)

TechProfileDownloadMessage = _reflection.GeneratedProtocolMessageType('TechProfileDownloadMessage', (_message.Message,), {
  'DESCRIPTOR' : _TECHPROFILEDOWNLOADMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.TechProfileDownloadMessage)
  })
_sym_db.RegisterMessage(TechProfileDownloadMessage)

DeleteGemPortMessage = _reflection.GeneratedProtocolMessageType('DeleteGemPortMessage', (_message.Message,), {
  'DESCRIPTOR' : _DELETEGEMPORTMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.DeleteGemPortMessage)
  })
_sym_db.RegisterMessage(DeleteGemPortMessage)

DeleteTcontMessage = _reflection.GeneratedProtocolMessageType('DeleteTcontMessage', (_message.Message,), {
  'DESCRIPTOR' : _DELETETCONTMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.DeleteTcontMessage)
  })
_sym_db.RegisterMessage(DeleteTcontMessage)

OnuIndicationMessage = _reflection.GeneratedProtocolMessageType('OnuIndicationMessage', (_message.Message,), {
  'DESCRIPTOR' : _ONUINDICATIONMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.OnuIndicationMessage)
  })
_sym_db.RegisterMessage(OnuIndicationMessage)

TechProfileInstanceRequestMessage = _reflection.GeneratedProtocolMessageType('TechProfileInstanceRequestMessage', (_message.Message,), {
  'DESCRIPTOR' : _TECHPROFILEINSTANCEREQUESTMESSAGE,
  '__module__' : 'voltha_protos.inter_adapter_pb2'
  # @@protoc_insertion_point(class_scope:inter_adapter.TechProfileInstanceRequestMessage)
  })
_sym_db.RegisterMessage(TechProfileInstanceRequestMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import events_pb2 as voltha__protos_dot_events__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2


class AdapterServiceStub(object):
    """AdapterService is a gRPC service to serve requests from Voltha RW_Core.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHealthStatus = channel.stream_stream(
                '/adapter_service.AdapterService/GetHealthStatus',
                request_serializer=voltha__protos_dot_common__pb2.Connection.SerializeToString,
                response_deserializer=voltha__protos_dot_health__pb2.HealthStatus.FromString,
                )
        self.AdoptDevice = channel.unary_unary(
                '/adapter_service.AdapterService/AdoptDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReconcileDevice = channel.unary_unary(
                '/adapter_service.AdapterService/ReconcileDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDevice = channel.unary_unary(
                '/adapter_service.AdapterService/DeleteDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisableDevice = channel.unary_unary(
                '/adapter_service.AdapterService/DisableDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReEnableDevice = channel.unary_unary(
                '/adapter_service.AdapterService/ReEnableDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RebootDevice = channel.unary_unary(
                '/adapter_service.AdapterService/RebootDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SelfTestDevice = channel.unary_unary(
                '/adapter_service.AdapterService/SelfTestDevice',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOfpDeviceInfo = channel.unary_unary(
                '/adapter_service.AdapterService/GetOfpDeviceInfo',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=voltha__protos_dot_core__adapter__pb2.SwitchCapability.FromString,
                )
        self.ChildDeviceLost = channel.unary_unary(
                '/adapter_service.AdapterService/ChildDeviceLost',
                request_serializer=voltha__protos_dot_device__pb2.Device.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.EnablePort = channel.unary_unary(
                '/adapter_service.AdapterService/EnablePort',
                request_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisablePort = channel.unary_unary(
                '/adapter_service.AdapterService/DisablePort',
                request_serializer=voltha__protos_dot_device__pb2.Port.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFlowsBulk = channel.unary_unary(
                '/adapter_service.AdapterService/UpdateFlowsBulk',
                request_serializer=voltha__protos_dot_core__adapter__pb2.BulkFlows.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateFlowsIncrementally = channel.unary_unary(
                '/adapter_service.AdapterService/UpdateFlowsIncrementally',
                request_serializer=voltha__protos_dot_core__adapter__pb2.IncrementalFlows.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendPacketOut = channel.unary_unary(
                '/adapter_service.AdapterService/SendPacketOut',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PacketOut.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdatePmConfig = channel.unary_unary(
                '/adapter_service.AdapterService/UpdatePmConfig',
                request_serializer=voltha__protos_dot_core__adapter__pb2.PmConfigsInfo.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DownloadOnuImage = channel.unary_unary(
                '/adapter_service.AdapterService/DownloadOnuImage',
                request_serializer=voltha__protos_dot_device__pb2.DeviceImageDownloadRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
                )
        self.GetOnuImageStatus = channel.unary_unary(
                '/adapter_service.AdapterService/GetOnuImageStatus',
                request_serializer=voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
                )
        self.AbortOnuImageUpgrade = channel.unary_unary(
                '/adapter_service.AdapterService/AbortOnuImageUpgrade',
                request_serializer=voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
                )
        self.GetOnuImages = channel.unary_unary(
                '/adapter_service.AdapterService/GetOnuImages',
                request_serializer=voltha__protos_dot_common__pb2.ID.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.OnuImages.FromString,
                )
        self.ActivateOnuImage = channel.unary_unary(
                '/adapter_service.AdapterService/ActivateOnuImage',
                request_serializer=voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
                )
        self.CommitOnuImage = channel.unary_unary(
                '/adapter_service.AdapterService/CommitOnuImage',
                request_serializer=voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
                )
        self.DownloadImage = channel.unary_unary(
                '/adapter_service.AdapterService/DownloadImage',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.GetImageDownloadStatus = channel.unary_unary(
                '/adapter_service.AdapterService/GetImageDownloadStatus',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.CancelImageDownload = channel.unary_unary(
                '/adapter_service.AdapterService/CancelImageDownload',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.ActivateImageUpdate = channel.unary_unary(
                '/adapter_service.AdapterService/ActivateImageUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.RevertImageUpdate = channel.unary_unary(
                '/adapter_service.AdapterService/RevertImageUpdate',
                request_serializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_device__pb2.ImageDownload.FromString,
                )
        self.StartOmciTest = channel.unary_unary(
                '/adapter_service.AdapterService/StartOmciTest',
                request_serializer=voltha__protos_dot_core__adapter__pb2.OMCITest.SerializeToString,
                response_deserializer=voltha__protos_dot_omci__test__pb2.TestResponse.FromString,
                )
        self.SimulateAlarm = channel.unary_unary(
                '/adapter_service.AdapterService/SimulateAlarm',
                request_serializer=voltha__protos_dot_core__adapter__pb2.SimulateAlarmMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_common__pb2.OperationResp.FromString,
                )
        self.SuppressEvent = channel.unary_unary(
                '/adapter_service.AdapterService/SuppressEvent',
                request_serializer=voltha__protos_dot_events__pb2.EventFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UnSuppressEvent = channel.unary_unary(
                '/adapter_service.AdapterService/UnSuppressEvent',
                request_serializer=voltha__protos_dot_events__pb2.EventFilter.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetExtValue = channel.unary_unary(
                '/adapter_service.AdapterService/GetExtValue',
                request_serializer=voltha__protos_dot_core__adapter__pb2.GetExtValueMessage.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.ReturnValues.FromString,
                )
        self.SetExtValue = channel.unary_unary(
                '/adapter_service.AdapterService/SetExtValue',
                request_serializer=voltha__protos_dot_core__adapter__pb2.SetExtValueMessage.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetSingleValue = channel.unary_unary(
                '/adapter_service.AdapterService/GetSingleValue',
                request_serializer=voltha__protos_dot_extensions__pb2.SingleGetValueRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.SingleGetValueResponse.FromString,
                )
        self.SetSingleValue = channel.unary_unary(
                '/adapter_service.AdapterService/SetSingleValue',
                request_serializer=voltha__protos_dot_extensions__pb2.SingleSetValueRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.SingleSetValueResponse.FromString,
                )


class AdapterServiceServicer(object):
    """AdapterService is a gRPC service to serve requests from Voltha RW_Core.
    """

    def GetHealthStatus(self, request_iterator, context):
        """GetHealthStatus is used by an AdapterService client to verify connectivity
        to the gRPC server hosting the AdapterService service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdoptDevice(self, request, context):
        """Device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconcileDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReEnableDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RebootDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfTestDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOfpDeviceInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChildDeviceLost(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnablePort(self, request, context):
        """Ports
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisablePort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFlowsBulk(self, request, context):
        """Flows
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFlowsIncrementally(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendPacketOut(self, request, context):
        """Packets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePmConfig(self, request, context):
        """PM
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadOnuImage(self, request, context):
        """Image
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnuImageStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortOnuImageUpgrade(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOnuImages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateOnuImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitOnuImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadImage(self, request, context):
        """Deprecated Image APIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageDownloadStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelImageDownload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateImageUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevertImageUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartOmciTest(self, request, context):
        """Tests
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimulateAlarm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuppressEvent(self, request, context):
        """Events
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnSuppressEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtValue(self, request, context):
        """Get/Set
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetExtValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSingleValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSingleValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdapterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHealthStatus': grpc.stream_stream_rpc_method_handler(
                    servicer.GetHealthStatus,
                    request_deserializer=voltha__protos_dot_common__pb2.Connection.FromString,
                    response_serializer=voltha__protos_dot_health__pb2.HealthStatus.SerializeToString,
            ),
            'AdoptDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.AdoptDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReconcileDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconcileDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisableDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReEnableDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.ReEnableDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RebootDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.RebootDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SelfTestDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfTestDevice,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOfpDeviceInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOfpDeviceInfo,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=voltha__protos_dot_core__adapter__pb2.SwitchCapability.SerializeToString,
            ),
            'ChildDeviceLost': grpc.unary_unary_rpc_method_handler(
                    servicer.ChildDeviceLost,
                    request_deserializer=voltha__protos_dot_device__pb2.Device.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'EnablePort': grpc.unary_unary_rpc_method_handler(
                    servicer.EnablePort,
                    request_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisablePort': grpc.unary_unary_rpc_method_handler(
                    servicer.DisablePort,
                    request_deserializer=voltha__protos_dot_device__pb2.Port.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFlowsBulk': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFlowsBulk,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.BulkFlows.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateFlowsIncrementally': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFlowsIncrementally,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.IncrementalFlows.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendPacketOut': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPacketOut,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PacketOut.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdatePmConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePmConfig,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.PmConfigsInfo.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DownloadOnuImage': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadOnuImage,
                    request_deserializer=voltha__protos_dot_device__pb2.DeviceImageDownloadRequest.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceImageResponse.SerializeToString,
            ),
            'GetOnuImageStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnuImageStatus,
                    request_deserializer=voltha__protos_dot_device__pb2.DeviceImageRequest.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceImageResponse.SerializeToString,
            ),
            'AbortOnuImageUpgrade': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortOnuImageUpgrade,
                    request_deserializer=voltha__protos_dot_device__pb2.DeviceImageRequest.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceImageResponse.SerializeToString,
            ),
            'GetOnuImages': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOnuImages,
                    request_deserializer=voltha__protos_dot_common__pb2.ID.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.OnuImages.SerializeToString,
            ),
            'ActivateOnuImage': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateOnuImage,
                    request_deserializer=voltha__protos_dot_device__pb2.DeviceImageRequest.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceImageResponse.SerializeToString,
            ),
            'CommitOnuImage': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitOnuImage,
                    request_deserializer=voltha__protos_dot_device__pb2.DeviceImageRequest.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.DeviceImageResponse.SerializeToString,
            ),
            'DownloadImage': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadImage,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'GetImageDownloadStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImageDownloadStatus,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'CancelImageDownload': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelImageDownload,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'ActivateImageUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateImageUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'RevertImageUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.RevertImageUpdate,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.FromString,
                    response_serializer=voltha__protos_dot_device__pb2.ImageDownload.SerializeToString,
            ),
            'StartOmciTest': grpc.unary_unary_rpc_method_handler(
                    servicer.StartOmciTest,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.OMCITest.FromString,
                    response_serializer=voltha__protos_dot_omci__test__pb2.TestResponse.SerializeToString,
            ),
            'SimulateAlarm': grpc.unary_unary_rpc_method_handler(
                    servicer.SimulateAlarm,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.SimulateAlarmMessage.FromString,
                    response_serializer=voltha__protos_dot_common__pb2.OperationResp.SerializeToString,
            ),
            'SuppressEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.SuppressEvent,
                    request_deserializer=voltha__protos_dot_events__pb2.EventFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UnSuppressEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.UnSuppressEvent,
                    request_deserializer=voltha__protos_dot_events__pb2.EventFilter.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtValue,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.GetExtValueMessage.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.ReturnValues.SerializeToString,
            ),
            'SetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetExtValue,
                    request_deserializer=voltha__protos_dot_core__adapter__pb2.SetExtValueMessage.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetSingleValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSingleValue,
                    request_deserializer=voltha__protos_dot_extensions__pb2.SingleGetValueRequest.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.SingleGetValueResponse.SerializeToString,
            ),
            'SetSingleValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSingleValue,
                    request_deserializer=voltha__protos_dot_extensions__pb2.SingleSetValueRequest.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.SingleSetValueResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'adapter_service.AdapterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AdapterService(object):
    """AdapterService is a gRPC service to serve requests from Voltha RW_Core.
    """

    @staticmethod
    def GetHealthStatus(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/adapter_service.AdapterService/GetHealthStatus',
            voltha__protos_dot_common__pb2.Connection.SerializeToString,
            voltha__protos_dot_health__pb2.HealthStatus.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdoptDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/AdoptDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReconcileDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/ReconcileDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/DeleteDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/DisableDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReEnableDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/ReEnableDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RebootDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/RebootDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfTestDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SelfTestDevice',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOfpDeviceInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetOfpDeviceInfo',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            voltha__protos_dot_core__adapter__pb2.SwitchCapability.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChildDeviceLost(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/ChildDeviceLost',
            voltha__protos_dot_device__pb2.Device.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EnablePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/EnablePort',
            voltha__protos_dot_device__pb2.Port.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisablePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/DisablePort',
            voltha__protos_dot_device__pb2.Port.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFlowsBulk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/UpdateFlowsBulk',
            voltha__protos_dot_core__adapter__pb2.BulkFlows.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFlowsIncrementally(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/UpdateFlowsIncrementally',
            voltha__protos_dot_core__adapter__pb2.IncrementalFlows.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendPacketOut(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SendPacketOut',
            voltha__protos_dot_core__adapter__pb2.PacketOut.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePmConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/UpdatePmConfig',
            voltha__protos_dot_core__adapter__pb2.PmConfigsInfo.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadOnuImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/DownloadOnuImage',
            voltha__protos_dot_device__pb2.DeviceImageDownloadRequest.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnuImageStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetOnuImageStatus',
            voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortOnuImageUpgrade(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/AbortOnuImageUpgrade',
            voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOnuImages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetOnuImages',
            voltha__protos_dot_common__pb2.ID.SerializeToString,
            voltha__protos_dot_device__pb2.OnuImages.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateOnuImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/ActivateOnuImage',
            voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CommitOnuImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/CommitOnuImage',
            voltha__protos_dot_device__pb2.DeviceImageRequest.SerializeToString,
            voltha__protos_dot_device__pb2.DeviceImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/DownloadImage',
            voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageDownloadStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetImageDownloadStatus',
            voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelImageDownload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/CancelImageDownload',
            voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateImageUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/ActivateImageUpdate',
            voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevertImageUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/RevertImageUpdate',
            voltha__protos_dot_core__adapter__pb2.ImageDownloadMessage.SerializeToString,
            voltha__protos_dot_device__pb2.ImageDownload.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartOmciTest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/StartOmciTest',
            voltha__protos_dot_core__adapter__pb2.OMCITest.SerializeToString,
            voltha__protos_dot_omci__test__pb2.TestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimulateAlarm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SimulateAlarm',
            voltha__protos_dot_core__adapter__pb2.SimulateAlarmMessage.SerializeToString,
            voltha__protos_dot_common__pb2.OperationResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuppressEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SuppressEvent',
            voltha__protos_dot_events__pb2.EventFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnSuppressEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/UnSuppressEvent',
            voltha__protos_dot_events__pb2.EventFilter.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetExtValue',
            voltha__protos_dot_core__adapter__pb2.GetExtValueMessage.SerializeToString,
            voltha__protos_dot_extensions__pb2.ReturnValues.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SetExtValue',
            voltha__protos_dot_core__adapter__pb2.SetExtValueMessage.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSingleValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/GetSingleValue',
            voltha__protos_dot_extensions__pb2.SingleGetValueRequest.SerializeToString,
            voltha__protos_dot_extensions__pb2.SingleGetValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSingleValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/adapter_service.AdapterService/SetSingleValue',
            voltha__protos_dot_extensions__pb2.SingleSetValueRequest.SerializeToString,
            voltha__protos_dot_extensions__pb2.SingleSetValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2


class ExtensionStub(object):
    """Extension is a service to get and set specific attributes
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetExtValue = channel.unary_unary(
                '/extension.Extension/GetExtValue',
                request_serializer=voltha__protos_dot_extensions__pb2.SingleGetValueRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.SingleGetValueResponse.FromString,
                )
        self.SetExtValue = channel.unary_unary(
                '/extension.Extension/SetExtValue',
                request_serializer=voltha__protos_dot_extensions__pb2.SingleSetValueRequest.SerializeToString,
                response_deserializer=voltha__protos_dot_extensions__pb2.SingleSetValueResponse.FromString,
                )


class ExtensionServicer(object):
    """Extension is a service to get and set specific attributes
    """

    def GetExtValue(self, request, context):
        """Get a single attribute
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetExtValue(self, request, context):
        """Set a single attribute
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExtensionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtValue,
                    request_deserializer=voltha__protos_dot_extensions__pb2.SingleGetValueRequest.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.SingleGetValueResponse.SerializeToString,
            ),
            'SetExtValue': grpc.unary_unary_rpc_method_handler(
                    servicer.SetExtValue,
                    request_deserializer=voltha__protos_dot_extensions__pb2.SingleSetValueRequest.FromString,
                    response_serializer=voltha__protos_dot_extensions__pb2.SingleSetValueResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'extension.Extension', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Extension(object):
    """Extension is a service to get and set specific attributes
    """

    @staticmethod
    def GetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/extension.Extension/GetExtValue',
            voltha__protos_dot_extensions__pb2.SingleGetValueRequest.SerializeToString,
            voltha__protos_dot_extensions__pb2.SingleGetValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetExtValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/extension.Extension/SetExtValue',
            voltha__protos_dot_extensions__pb2.SingleSetValueRequest.SerializeToString,
            voltha__protos_dot_extensions__pb2.SingleSetValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
